@@ -1189,6 +1189,10 @@ proc ::pki::x509::parse_cert {cert} {
 
 	array set ret [list]
 
+	# Include the raw certificate
+	set ret(raw) $cert
+	binary scan $ret(raw) H* ret(raw)
+
 	# Decode X.509 certificate, which is an ASN.1 sequence
 	::asn::asnGetSequence cert_seq wholething
 	::asn::asnGetSequence wholething cert
@@ -2129,4 +2133,4 @@ proc ::pki::rsa::generate {bitlength {exponent 0x10001}} {
 # # ## ### ##### ######## #############
 ## Ready
 
-package provide pki 0.8
+package provide pki 0.9
